fn fn_generic_params(
make: &SyntaxFactory,
ctx: &AssistContext<'_, '_>,
necessary_params: FxHashSet<GenericParam>,
target: &GeneratedFunctionTarget,
) -> Option<(Option<GenericParamList>, Option<WhereClause>)>Expand description
Gets parameter bounds and where predicates in scope and filters out irrelevant ones. Returns
None when it fails to get scope information.
See comment on filter_unnecessary_bounds() for what bounds we consider relevant.
NOTE: Generic parameters returned from this function may cause name clash at target. We don’t
currently do anything about it because it’s actually easy to resolve it after the assist: just
use the Rename functionality.