fn next_space_for_fn_after_call_site(
expr: CallableExpr,
) -> Option<GeneratedFunctionTarget>Expand description
Returns the position inside the current mod or file directly after the current block We want to write the generated function directly after fns, impls or macro calls, but inside mods